﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;
using TestTChart.Properties;

namespace TestTChart
{
    public partial class Form1 : Form
    {

        Line _chartLine;
        List<int> _badIndexes;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            _badIndexes = new List<int>();
            _badIndexes.Add(15);
            _badIndexes.Add(35);
            _badIndexes.Add(55);
            _chartLine = new Line(tChart1.Chart)
            {
                Title = "Test", 
                Color = Color.Blue, 
                Stairs = true,
                ColorEach = false,
                ColorEachLine = false,
                ClickableLine = false,
                Dark3D = false,
                TreatNulls = TreatNullsStyle.DoNotPaint, 
                LinePen = new ChartPen
                {
                    Width = 2,
                    Style = DashStyle.Solid,
                }, 
                DateTimeFormat = "dd/MM/yyyy HH:mm:ss.ff",
                Pointer = 
                {
                    InflateMargins = true, 
                    HorizSize = 4,
                    VertSize = 4,
                    Visible = true,     
                    Dark3D = false,
                    Draw3D = false,
                    Style = PointerStyles.Circle,
                }
            };
            _chartLine.AfterDrawValues += ChartLine_AfterDrawValues;
            _chartLine.BeforeDrawValues += ChartLine_BeforeDrawValues;
            _chartLine.FillSampleValues(100);
        }

        private void ChartLine_BeforeDrawValues(object sender, Graphics3D g)
        {
            Steema.TeeChart.Styles.Series s = sender as Steema.TeeChart.Styles.Series;
            int left = s.GetHorizAxis.IStartPos;
            int right = s.GetHorizAxis.IEndPos;
            int top = s.GetVertAxis.IStartPos;
            int bottom = s.GetVertAxis.IEndPos;
            _chartLine.Chart.Graphics3D.ClipRectangle(left, top, right, bottom);
        }

        private void ChartLine_AfterDrawValues(object sender, Graphics3D g)
        {
            foreach (int badIndex in _badIndexes)
            {
                if (badIndex < _chartLine.Count)
                {
                    Point p2 = new Point(_chartLine.CalcXPos(badIndex), _chartLine.CalcYPos(badIndex));
                    if (badIndex - 1 >= 0) 
                    {
                        g.Pen.Style = DashStyle.Solid;
                        g.Pen.Width = 2;
                        g.Pen.Color = Color.White;
                        Point p1 = new Point(_chartLine.CalcXPos(badIndex), _chartLine.CalcYPos(badIndex - 1));
                        g.Line(p1, p2);
                        g.Pen.Style = DashStyle.Dash;
                        g.Pen.Color = Color.Blue;
                        g.Line(p1, p2);
                    }
                    if (badIndex + 1 < _chartLine.Count) 
                    {
                        Point p3 = new Point(_chartLine.CalcXPos(badIndex + 1), _chartLine.CalcYPos(badIndex));
                        Point p4 = new Point(_chartLine.CalcXPos(badIndex + 1), _chartLine.CalcYPos(badIndex + 1));
                        g.Pen.Style = DashStyle.Solid;
                        g.Pen.Width = 2;
                        g.Pen.Color = Color.White;
                        g.Line(p2, p3);
                        g.Line(p3, p4);
                        g.Pen.Style = DashStyle.Dash;
                        g.Pen.Color = Color.Blue;
                        g.Line(p2, p3);
                        g.Line(p3, p4);
                    }
                }
            }

            tChart1.Graphics3D.ClearClipRegions();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            tChart1.Graphics3D.ClipRectangle(tChart1.Chart.ChartRect);
            tChart1.Graphics3D.ClearClipRegions();
        }
    }
}
